library(dplyr)
library(tidyr)
library(ggplot2)
library(gridExtra)
library(sf)
library(blockCV)

source("R/utils.R")

# Combine presence-absence data
files = list.files("data/r_objects/pa_sampling/", full.names = T)

model_data = lapply(files, function(f){load(f); return(pa_spec)}) %>% 
  bind_rows() 
  
model_data_core = dplyr::filter(model_data, record_type == "core")
model_data_background = dplyr::filter(model_data, record_type == "background")
  
# Define global folds
spatial_folds = suppressMessages(
  blockCV::cv_spatial(
    model_data_core,
    column = "present",
    k = 5
  )
)

model_data_core$fold_global = spatial_folds$folds_ids
model_data = bind_rows(model_data_core, model_data_background) %>% 
  arrange(species) %>% 
  relocate(contains("fold"), .after = last_col()) %>% 
  mutate(species = as.factor(species))

# Save Model data
save(model_data, file = "data/r_objects/model_data.RData")
